/*
*  Name:      test-1.uesql.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for UESQL
*  Date:      $Date: 2000/08/02 22:30:09 $
*  Revision:  $Revision: 1.2 $
*
*  Copyright (C) 2000  Dedalo Ingenieros, S.L.
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <cstdlib>
#include <iostream>
#include <mpcl/config_processor.hh>
#include <mpcl/string.hh>
#include <mpcl/test.h>


//
//  L O C A L   V A R I A B L E S
//

static uesql::TSqlstateDescriptor   _tSqlstateDescriptor;
  

//
//  L O C A L   F U N C T I O N S
//

/**
*  Construct error message from SQL status.
*  @return SQL status message.
*/
static mpcl::xstring _GetErrorMessage (void)
{

  using mpcl::xstring;

  return ( xstring (_tSqlstateDescriptor.getClass())    +
           ": "                                         +
           xstring (_tSqlstateDescriptor.getSubclass()) +
           " (" + uesql::SQLMESSAGE + ")"               );

}  // _GetErrorMessage()


/**
*  Main.
*
*  Parameters:
*
*    {-o, --dbms-server-name}=DBMS-SERVER-NAME
*    {-u, --dbms-user-name}=DBMS-USER-NAME
*    {-p, --dbms-user-password}=PASSWORD
*/
int main (int argc, const char* argv[])
{

  using mpcl::Format;
  using mpcl::TConfigProcessor;
  using mpcl::xstring;
  using uesql::TSqlString;
  
  TEST_INIT ("Test for SCHEMA related statements");
  TEST_START_WATCH;

  TConfigProcessor   tConfig;
  TSqlString         yVar0;
  TSqlString         yVar1;
  TSqlString         yVar2;
  TSqlString         yCursorName;
  TSqlString         yDbmsUserLogin;
  TSqlString         yDbmsSchemaLocation;
  TSqlString         yDbmsServerName;
  const char*        pcDbmsServerName = getenv ("DBMS_SERVER_NAME");
  const char*        pcDbmsUserName   = getenv ("DBMS_USER_NAME");
  TSqlString         yCodeValue       = "002";

  try
  {
    //
    //  Checks environment variables.
    //
    if ( !pcDbmsServerName )
    {
      pcDbmsServerName = "localhost";
    }
    if ( !pcDbmsUserName )
    {
      pcDbmsUserName = getenv ("USER");
      if ( !pcDbmsUserName )
      {
        pcDbmsUserName = "";
      }
    }
    
    //
    //  Define string constants names for options.
    //
    tConfig.addOption ("dbms-server-name",   "o", pcDbmsServerName);
    tConfig.addOption ("dbms-user-name",     "u", pcDbmsUserName);
    tConfig.addOption ("dbms-user-password", "p", pcDbmsUserName);
    tConfig.setCommandLineParameters (argc, argv);
    tConfig.processOptions();
    
    yDbmsServerName     = tConfig ["dbms-server-name"].value();
    yDbmsUserLogin      = tConfig ["dbms-user-name"].value();
    yDbmsSchemaLocation = uesql::ComposeSchemaLocation (yDbmsServerName, tConfig ["dbms-user-name"].value());
    if ( !tConfig ["dbms-user-password"].value().empty() )
    {
      yDbmsUserLogin = uesql::ComposeUserLogin
                       (
                         yDbmsUserLogin                         ,
                         tConfig ["dbms-user-password"].value() 
                       );
    }
  }
  catch (const mpcl::TBaseException& rktSOURCE_EXCEPTION)
  {
    cerr << rktSOURCE_EXCEPTION;
    TEST_FAIL_WITH_CODE (3);
  }

  TEST_WRITE_INFO ("DBMS-SCHEMA-LOCATION = %s", yDbmsSchemaLocation.c_str());
  TEST_WRITE_INFO ("DBMS-USER-LOGIN      = %s", yDbmsUserLogin.c_str());
  if ( !yDbmsServerName.empty() && !yDbmsUserLogin.empty() )
  {
    extern "UESQL::default" 
    {
      --
      --  Whenever any SQLERROR condition goto label 'error'.
      --
      whenever sqlerror goto error;
      
      --
      --  Connects to default schema.
      --
      connect to :uesql::Quote (yDbmsServerName)
        user :uesql::Quote (yDbmsUserLogin);

      --
      --  Creates schema TEST_1_SCHEMA.
      --
      create schema TEST_1_SCHEMA
        create table TABLE_1
        (
          CODE         character (3) not null ,
          WORKER_COUNT integer
        )
        create table TABLE_2
        (
          WORK_CODE character (3)  not null ,
          NAME      character (40) not null ,
          HOURS     decimal   (5)
        );

      --
      --  Connects to the newly created schema.
      --
      connect to :uesql::ComposeQuotedSchemaLocation (yDbmsServerName, "TEST_1_SCHEMA")
        as 'myconnection'
        user :uesql::Quote (yDbmsUserLogin);

      --
      --  Removes tables.
      --
      drop table TABLE_1 cascade;
      disconnect current;
      set connection default;

      --
      --  Removes schema TEST_1_SCHEMA.
      --
      drop schema TEST_1_SCHEMA cascade;
    }
  }
  goto end;

error:
  cerr << "SQLSTATE="    << uesql::SQLSTATE    << endl;
  cerr << "SQLCODE="     << uesql::SQLCODE     << endl;
  cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
  TEST_FAIL_WITH_CODE (uesql::SQLCODE);

end:
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
